@@ -914,6 +914,7 @@ class BigQueryExecutor:
             )
         except exceptions.Conflict as error:
             logging.error(error)
+            raise error
 
 
     def load_google_sheet(self,
@@ -961,8 +962,9 @@ class BigQueryExecutor:
                 write_disposition=write_disposition,
                 sql=f"SELECT * FROM `{project_id}.{dataset_id}.{temp_table_id}`"
             )
-        except Exception as e:
-            logging.error(e)
+        except Exception as error:
+            logging.error(error)
+            raise error
         finally:
             if self.table_exists(dataset_id=dataset_id, table_id=temp_table_id):
                 self.delete_table(dataset_id=dataset_id, table_id=temp_table_id)
@@ -1443,6 +1445,9 @@ class BigQueryExecutor:
         Returns:
             non-negative integer
         """
+        if not primary_key:
+            logging.warning("No primary key supplied, skipping duplicates count.")
+            return 0
         data = self.execute_sql(
             f"""
             SELECT
@@ -1476,7 +1481,7 @@ class BigQueryExecutor:
             Raise and log AssertionError if there are duplicate rows and ignore_error=False (default)
             Log a warning if there are dupicate rows and ignore_error=True (debugging)
         """
-        if self.count_duplicates(table_id, primary_key, dataset_id,project_id = project_id) != 0:
+        if self.count_duplicates(table_id, primary_key, dataset_id, project_id=project_id) != 0:
             msg = "Table %s:%s.%s is not unique on %s" % (
                 project_id,
                 dataset_id,
